==> php81-nextcloud-30.0.2.tgz: share/nextcloud/apps/systemtags/l10n/ca.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "El sistema ha afegit l'etiqueta del sistema %1$s",
    "Added system tag {systemtag}" : "S'ha afegit l'etiqueta del sistema {systemtag}",
    "Added system tag %1$s" : "S'ha afegit l'etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha afegit l'etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha afegit l'etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "El sistema ha suprimit l'etiqueta del sistema %1$s",
    "Removed system tag {systemtag}" : "S'ha suprimit l'etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "S'ha suprimit l'etiqueta del sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Heu creat l'etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Heu creat l'etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creat l'etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creat l'etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Heu suprimit l'etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Heu suprimit l'etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Heu actualitzat l'etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Heu actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha actualitzat l'etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "El sistema ha afegit l'etiqueta del sistema %2$s a %1$s",
    "System tag {systemtag} was added to {file} by the system" : "El sistema ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "You added system tag %2$s to %1$s" : "Heu afegit l'etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Heu afegit l'etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha afegit l'etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "El sistema ha suprimit l'etiqueta del sistema %2$s de %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "El sistema ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "You removed system tag %2$s from %1$s" : "Heu suprimit l'etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Heu suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha suprimit l'etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringit)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "S'han modificat les <strong>etiquetes del sistema</strong> d'un fitxer",
    "Files" : "Fitxers",
    "Tags" : "Etiquetes",
    "All tagged %s …" : "Tots els elements amb l'etiqueta %s…",
    "tagged %s" : "amb l'etiqueta %s",
    "Collaborative tags" : "Etiquetes col·laboratives",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre persones.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre persones. Fantàstica per a equips.\n\t(Si sou un proveïdor amb una instància del Nextcloud per a diversos clients, s'aconsella inhabilitar aquesta aplicació perquè les etiquetes es comparteixen amb tothom.)",
    "Create or edit tags" : "Creeu o editeu etiquetes",
    "Search for a tag to edit" : "Cerqueu l'etiqueta que voleu editar",
    "Collaborative tags …" : "Etiquetes col·laboratives…",
    "No tags to select" : "No hi ha cap etiqueta per seleccionar",
    "Tag name" : "Nom de l'etiqueta",
    "Tag level" : "Nivell de l'etiqueta",
    "Create" : "Crea",
    "Update" : "Actualitza",
    "Delete" : "Suprimeix",
    "Reset" : "Reinicialitza",
    "Loading …" : "S'està carregant…",
    "Public" : "Públic",
    "Restricted" : "Restringit",
    "Invisible" : "Invisible",
    "Created tag" : "S'ha creat l'etiqueta",
    "Failed to create tag" : "No s'ha pogut crear l'etiqueta",
    "Updated tag" : "S'ha actualitzat l'etiqueta",
    "Failed to update tag" : "No s'ha pogut actualitzar l'etiqueta",
    "Deleted tag" : "S'ha suprimit l'etiqueta",
    "Failed to delete tag" : "No s'ha pogut suprimir l'etiqueta",
    "Manage tags" : "Gestiona les etiquetes",
    "No tags found" : "No s'ha trobat cap etiqueta",
    "Cancel" : "Cancel·la",
    "Loading collaborative tags …" : "S'estan carregant les etiquetes col·laboratives…",
    "Search or create collaborative tags" : "Cerqueu o creeu etiquetes col·laboratives",
    "No tags to select, type to create a new tag" : "No hi ha cap etiqueta per seleccionar, escriviu per a crear una etiqueta nova",
    "Failed to load tags" : "No s'han pogut carregar les etiquetes",
    "Failed to load selected tags" : "No s'han pogut carregar les etiquetes seleccionades",
    "Failed to select tag" : "No s'ha pogut seleccionar l'etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes col·laboratives estan disponibles per a tots els usuaris. Els usuaris poden veure les etiquetes restringides, però no les poden assignar. Les etiquetes invisibles són per a ús intern, perquè els usuaris no poden ni veure-les ni assignar-les.",
    "Open in Files" : "Obre a Fitxers",
    "List of tags and their associated files and folders." : "Llista d'etiquetes i els fitxers i carpetes associats.",
    "Tags you have created will show up here." : "Les etiquetes que heu creat es mostraran aquí.",
    "Failed to load last used tags" : "No s'han pogut carregar les etiquetes utilitzades recentment",
    "Missing \"Content-Location\" header" : "Falta la capçalera «Content-Location»",
    "Failed to load tags for file" : "No s'han pogut carregar les etiquetes del fitxer",
    "Failed to set tag for file" : "No s'ha pogut definit l'etiqueta per al fitxer",
    "Failed to delete tag for file" : "No s'ha pogut suprimir l'etiqueta del fitxer",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre usuaris.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre usuaris. Fantàstica per a equips.\n\t(Si sou un proveïdor amb una instància del Nextcloud per a diversos clients, s'aconsella inhabilitar aquesta aplicació perquè les etiquetes es comparteixen amb tothom.)",
    "This file has the tag {tag}" : "Aquest fitxer té l'etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Aquest fitxer té les etiquetes {firstTags} i {lastTag}",
    "No files in here" : "No hi ha cap fitxer aquí",
    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Data de modificació"
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-30.0.11.tgz: share/nextcloud/apps/systemtags/l10n/ca.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s afegida pel sistema",
    "Added system tag {systemtag}" : "S'ha afegit l'etiqueta del sistema {systemtag}",
    "Added system tag %1$s" : "S'ha afegit l'etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha afegit l'etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha afegit l'etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "El sistema ha suprimit l'etiqueta del sistema %1$s",
    "Removed system tag {systemtag}" : "S'ha suprimit l'etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "S'ha suprimit l'etiqueta del sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Heu creat l'etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Heu creat l'etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creat l'etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creat l'etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Heu suprimit l'etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Heu suprimit l'etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Heu actualitzat l'etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Heu actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha actualitzat l'etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "El sistema ha afegit l'etiqueta del sistema %2$s a %1$s",
    "System tag {systemtag} was added to {file} by the system" : "El sistema ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "You added system tag %2$s to %1$s" : "Heu afegit l'etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Heu afegit l'etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha afegit l'etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "El sistema ha suprimit l'etiqueta del sistema %2$s de %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "El sistema ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "You removed system tag %2$s from %1$s" : "Heu suprimit l'etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Heu suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha suprimit l'etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringit)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "S'han modificat les <strong>etiquetes del sistema</strong> d'un fitxer",
    "Files" : "Fitxers",
    "Tags" : "Etiquetes",
    "All tagged %s …" : "Tots els elements amb l'etiqueta %s…",
    "tagged %s" : "amb l'etiqueta %s",
    "Collaborative tags" : "Etiquetes col·laboratives",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre persones.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre persones. Fantàstica per a equips.\n\t(Si sou un proveïdor amb una instància del Nextcloud per a diversos clients, s'aconsella inhabilitar aquesta aplicació perquè les etiquetes es comparteixen amb tothom.)",
    "Public" : "Públic",
    "Restricted" : "Restringit",
    "Invisible" : "Invisible",
    "Created tag" : "S'ha creat l'etiqueta",
    "Failed to create tag" : "No s'ha pogut crear l'etiqueta",
    "Updated tag" : "S'ha actualitzat l'etiqueta",
    "Failed to update tag" : "No s'ha pogut actualitzar l'etiqueta",
    "Deleted tag" : "S'ha suprimit l'etiqueta",
    "Failed to delete tag" : "No s'ha pogut suprimir l'etiqueta",
    "Create or edit tags" : "Creeu o editeu etiquetes",
    "Search for a tag to edit" : "Cerqueu l'etiqueta que voleu editar",
    "Collaborative tags …" : "Etiquetes col·laboratives…",
    "No tags to select" : "No hi ha cap etiqueta per seleccionar",
    "Tag name" : "Nom de l'etiqueta",
    "Tag level" : "Nivell de l'etiqueta",
    "Create" : "Crea",
    "Update" : "Actualitza",
    "Delete" : "Suprimeix",
    "Reset" : "Reinicialitza",
    "Loading …" : "S'està carregant…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["S'establirà {tag1} i s'eliminarà {tag2} d'1 fitxer.","S'establirà {tag1} i s'eliminaran {tag2} de {count} fitxers."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} s'establirà en 1 fitxer.","{tag} s'establirà en {count} fitxers."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} s'eliminarà d'1 fitxer.","{tag} s'eliminarà de {count} fitxers."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} i {lastTag} s'establiran en 1 fitxer.","{tags} i {lastTag} s'establiran en {count} fitxers."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} i {lastTag} s'eliminaran d'1 fitxer.","{tags} i {lastTag} s'eliminaran de {count} fitxers."],
    "{displayName} (hidden)" : "{displayName} (amagat)",
    "{displayName} (restricted)" : "{displayName} (restringit)",
    "Only admins can create new tags" : "Només els administradors poden crear etiquetes noves",
    "Failed to apply tags changes" : "No s'han pogut aplicar els canvis d'etiquetes",
    "File tags modification canceled" : "S'ha cancel·lat la modificació de les etiquetes del fitxer",
    "Manage tags" : "Administrar les etiquetes",
    "Applying tags changes…" : "S'estan aplicant els canvis d'etiquetes…",
    "Search or create tag" : "Cerca o crea una etiqueta",
    "Search tag" : "Etiqueta de cerca",
    "Change tag color" : "Canvia el color de l'etiqueta",
    "Create new tag" : "Crea una etiqueta nova",
    "Select or create tags to apply to all selected files" : "Seleccioneu o creeu etiquetes per aplicar-les a tots els fitxers seleccionats",
    "Select tags to apply to all selected files" : "Seleccioneu les etiquetes per aplicar a tots els fitxers seleccionats",
    "Cancel" : "Cancel·la",
    "Apply changes" : "Aplica els canvis",
    "Failed to load tags" : "No s'han pogut carregar les etiquetes",
    "Failed to load selected tags" : "No s'han pogut carregar les etiquetes seleccionades",
    "Failed to select tag" : "No s'ha pogut seleccionar l'etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "L'administrador del sistema ha desactivat la creació d'etiquetes. Només podeu utilitzar els existents.",
    "Loading collaborative tags …" : "S'estan carregant les etiquetes col·laboratives…",
    "Search or create collaborative tags" : "Cerqueu o creeu etiquetes col·laboratives",
    "No tags to select, type to create a new tag" : "No hi ha cap etiqueta per seleccionar, escriviu per a crear una etiqueta nova",
    "Unable to update setting" : "No es pot actualitzar el paràmetre",
    "System tag creation is now restricted to administrators" : "La creació d'etiquetes del sistema ara està restringida als administradors",
    "System tag creation is now allowed for everybody" : "La creació d'etiquetes del sistema ara està permesa per a tothom",
    "System tag management" : "Gestió d'etiquetes del sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si està habilitat, només els administradors poden crear i editar etiquetes. Els comptes encara poden assignar-los i eliminar-los dels fitxers.",
    "Restrict tag creation and editing to administrators" : "Restringeix la creació i edició d'etiquetes als administradors",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes col·laboratives estan disponibles per a tots els usuaris. Els usuaris poden veure les etiquetes restringides, però no les poden assignar. Les etiquetes invisibles són per a ús intern, perquè els usuaris no poden ni veure-les ni assignar-les.",
    "Assigned collaborative tags" : "Etiquetes col·laboratives assignades",
    "Open in Files" : "Obre a Fitxers",
    "List of tags and their associated files and folders." : "Llista d'etiquetes i els fitxers i carpetes associats.",
    "No tags found" : "No s'ha trobat cap etiqueta",
    "Tags you have created will show up here." : "Les etiquetes que heu creat es mostraran aquí.",
    "Failed to load tag" : "No s'ha pogut carregar l'etiqueta",
    "Failed to load last used tags" : "No s'han pogut carregar les etiquetes utilitzades recentment",
    "Missing \"Content-Location\" header" : "Falta la capçalera «Content-Location»",
    "A tag with the same name already exists" : "Ja existeix una etiqueta amb el mateix nom",
    "Failed to load tags for file" : "No s'han pogut carregar les etiquetes del fitxer",
    "Failed to set tag for file" : "No s'ha pogut definit l'etiqueta per al fitxer",
    "Failed to delete tag for file" : "No s'ha pogut suprimir l'etiqueta del fitxer",
    "This file has the tag {tag}" : "Aquest fitxer té l'etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Aquest fitxer té les etiquetes {firstTags} i {lastTag}"
},
"nplurals=2; plural=(n != 1);");
